==> alfresco-repository-23.7.0.16-sources.jar: org/alfresco/repo/invitation/ModeratedInvitationProcess.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.invitation;

import org.alfresco.service.cmr.invitation.Invitation;

/**
 * The Moderated Invitation Process has a moderator who approves or rejects 
 * invitations raised by the invitee themselves.
 *
 * Upon approval the invitee will be given the requested role for the 
 * requested resource.
 */

public interface ModeratedInvitationProcess extends InvitationProcess
{
    /**
     * Invitee kicks off process
     * @param request Invitation
     * @param reason String
     */
    public Invitation invite(Invitation request, String reason);

    /**
     * Moderator approves this request
     * @param request the request to approve.
     */
    public void approve(Invitation request, String reason);

    /**
     * Moderator rejects this request
     * @param request the request to reject
     */
    public void reject(Invitation request, String reason);

    /**
     * Invitee cancels this request
     */
    public void cancel (Invitation request, String reason);
}

==> alfresco-repository-25.2.1.1-sources.jar: org/alfresco/repo/invitation/ModeratedInvitationProcess.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.invitation;

import org.alfresco.service.cmr.invitation.Invitation;

/**
 * The Moderated Invitation Process has a moderator who approves or rejects invitations raised by the invitee themselves.
 *
 * Upon approval the invitee will be given the requested role for the requested resource.
 */

public interface ModeratedInvitationProcess extends InvitationProcess
{
    /**
     * Invitee kicks off process
     * 
     * @param request
     *            Invitation
     * @param reason
     *            String
     */
    public Invitation invite(Invitation request, String reason);

    /**
     * Moderator approves this request
     * 
     * @param request
     *            the request to approve.
     */
    public void approve(Invitation request, String reason);

    /**
     * Moderator rejects this request
     * 
     * @param request
     *            the request to reject
     */
    public void reject(Invitation request, String reason);

    /**
     * Invitee cancels this request
     */
    public void cancel(Invitation request, String reason);
}
